@@ -89,12 +89,6 @@ Possible config properties for Log::Log4perl::Appender::DBI are
     (patternLayout).dontCollapseArrayRefs 0|1
     
     
-=head1 AUTHORS
-
-    Kevin Goess, <cpan@goess.org> 
-    
-    December, 2002
-
 =head1 SEE ALSO
 
 http://jakarta.apache.org/log4j/docs/
@@ -103,4 +97,12 @@ Log::Log4perl::Javamap
 
 Log::Log4perl::Appender::DBI
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2002-2009 by Mike Schilli E<lt>m@perlmeister.comE<gt> 
+and Kevin Goess E<lt>cpan@goess.orgE<gt>.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
+
 =cut
